@@ -974,6 +974,7 @@ REFERENCE_TABLE_BRAVAIS_TYPE_CENTRING_TYPE_CRYSTAL_SYSTEM = (
     ("mS", "A", "monoclinic"),
     ("mS", "B", "monoclinic"),
     ("mS", "C", "monoclinic"),
+    ("mI", "I", "monoclinic"),
     ("oP", "P", "orthorhombic"),
     ("oS", "A", "orthorhombic"),
     ("oS", "B", "orthorhombic"),
@@ -1266,14 +1267,16 @@ def get_symop_pcentr_multiplicity_letter_site_symmetry_coords_xyz_2(
         # else:  # hexagonal
         choice = "1"
     elif "r" in it_coordinate_system_code:
-        choice = "1"
+        choice = "2"
     else:
         choice = "1"
     symop, p_centr = None, None
     for _el_card in EL_CARDS:
         if ((_el_card["it_number"] == it_number) & (_el_card["choice"][0] == choice)):
             symop = tuple(_el_card["symmetry"])
-            p_centr = array([Fraction(_).limit_denominator(10) for _ in _el_card["pcentr"][0].split(",")],
+            # FIXME: It looks that definition of p_centr is inversed one compare with parameters given in card (at least for 227 choise 1)
+            # It should be checked for all space group. It is why here factor -1.
+            p_centr = -1*array([Fraction(_).limit_denominator(10) for _ in _el_card["pcentr"][0].split(",")],
                              dtype=Fraction)
             break
     _s_name, _choice = get_transform_pp_abc_choice_by_it_number_it_coordinate_system_code(it_number,
@@ -1488,184 +1491,3 @@ def is_good_for_mask(r, b, fract_x, fract_y, fract_z):
     flag_1 = is_solution_a_b(r, b_1)
     return flag_1
 
-
-# if __name__ == "__main__":
-#     print("List of functions: ")
-#     print("List of constants: ")
-
-
-#     def print_parameters_by_it_number_it_coordinate_system_code(it_number: int, it_coordinate_system_code=None):
-#         bravais_type, laue_class, patterson_name_hm, centring_type, crystal_system = None, None, None, None, None
-#         name_hm_extended, name_hm_full, name_hm_short = None, None, None
-#         name_hall, name_schoenflies, point_group_hm = None, None, None
-
-#         lattice_type = None
-#         generators = ()
-
-#         symop, pcentr, l_multiplicity, l_letter, l_site_symmetry, l_coord_xyz_2 = get_symop_pcentr_multiplicity_letter_site_symmetry_coords_xyz_2(
-#             it_number, it_coordinate_system_code)
-
-#         crystal_system = get_crystal_system_by_it_number(it_number)
-
-#         if it_coordinate_system_code is not None:
-#             it_c_s_c = it_coordinate_system_code
-#         else:
-#             it_c_s_c = get_default_it_coordinate_system_code_by_it_number(it_number)
-
-#         name_hm_extended = get_name_hm_extended_by_it_number_it_coordinate_system_code(it_number, it_c_s_c)
-#         if (name_hm_extended is not None):
-#             centring_type = get_centring_type_by_name_hm_extended(name_hm_extended)
-#         if ((centring_type is not None) & (crystal_system is not None)):
-#             bravais_type = get_bravais_type_by_centring_type_crystal_system(centring_type, crystal_system)
-
-#         name_hm_short = get_name_hm_short_by_it_number(it_number)
-#         if (name_hm_short is not None):
-#             lattice_type = get_lattice_type_by_name_hm_short(name_hm_short)
-
-#         hm_full = get_name_hm_full_by_it_number(it_number)
-#         name_hall = get_name_hall_by_it_number(it_number)
-#         if name_hall is not None:
-#             centrosymmetry = get_centrosymmetry_by_name_hall(name_hall)
-#         name_schoenflies = get_name_schoenflies_by_it_number(it_number)
-#         if name_schoenflies is not None:
-#             laue_class = get_laue_class_by_name_schoenflies(name_schoenflies)
-#             point_group_hm = get_point_group_hm_short_by_name_schoenflies(name_schoenflies)
-#             if point_group_hm is not None:
-#                 generators = get_generators_by_point_group_hm(point_group_hm)
-#             if ((lattice_type is not None) & (laue_class is not None)):
-#                 patterson_name_hm = get_patterson_name_hm_by_lattice_type_laue_class(lattice_type, laue_class)
-
-#         print(70 * "-")
-#         print("SPACE GROUP")
-#         width_left, width_right = 30, 40
-#         print(f"IT_number: ".rjust(width_left) + f"{it_number:}".ljust(width_right))
-#         if name_hm_extended is not None: print(
-#             "Name H-M extended: ".rjust(width_left) + f"\"{name_hm_extended:}\"".ljust(width_right))
-#         if name_hm_full is not None: print(
-#             f"Name H-M full: ".rjust(width_left) + f"\"{name_hm_full:}\"".ljust(width_right))
-#         if name_hm_short is not None: print(
-#             f"Name H-M short: ".rjust(width_left) + f"\"{name_hm_short:}\"".ljust(width_right))
-#         if name_hall is not None: print(f"Name Hall short: ".rjust(width_left) + f"\"{name_hall:}\"".ljust(width_right))
-#         if name_schoenflies is not None: print(
-#             f"Name Schoenflies: ".rjust(width_left) + f"\"{name_schoenflies:}\"".ljust(width_right))
-#         print(f"IT_coordinate_system_code: ".rjust(width_left) + f"\"{it_c_s_c:}\"".ljust(width_right))
-#         print()
-#         if point_group_hm is not None: print(
-#             f"Point group H-M: ".rjust(width_left) + f"\"{point_group_hm:}\"".ljust(width_right))
-#         if laue_class is not None: print(f"Laue class: ".rjust(width_left) + f"\"{laue_class:}\"".ljust(width_right))
-#         if patterson_name_hm is not None: print(
-#             f"Patterson name H-M: ".rjust(width_left) + f"\"{patterson_name_hm:}\"".ljust(width_right))
-#         if centring_type is not None: print(
-#             f"Centring type: ".rjust(width_left) + f"\"{centring_type:}\"".ljust(width_right))
-#         if bravais_type is not None: print(
-#             f"Bravais type: ".rjust(width_left) + f"\"{bravais_type:}\"".ljust(width_right))
-#         if crystal_system is not None: print(
-#             f"Crystal system: ".rjust(width_left) + f"\"{crystal_system:}\"".ljust(width_right))
-#         print()
-#         if centrosymmetry is not None: print(
-#             f"Centrosymmetry: ".rjust(width_left) + f"{'Yes' if centrosymmetry else 'No':}".ljust(width_right))
-#         if generators != (): print(
-#             f"Generators: ".rjust(width_left) + ", ".join([f"\"{_}\"" for _ in generators]).ljust(width_right))
-
-#         if symop is not None:
-#             print("Symop: ")  # pcentr
-#             print_long_list([f"\"{_:}\"" for _ in symop])
-
-#         print("Multiplicity letter syte_symmetry coord_xyz")
-#         for _1, _2, _3, _4 in zip(l_multiplicity, l_letter, l_site_symmetry, l_coord_xyz_2):
-#             print(f"{_1:} {_2:} {_3:} {('(' + '), ('.join(_4) + ')'):}")
-#         return
-
-
-#     def dialog():
-#         answ = input(
-#             "Introduce space group notation (IT_number, H-M, Hall, Schoenflies) \nand it_coordinate_system_code (if it is needed)\n(example: '8:-b2')\n..... ")
-#         notation, it_coordinate_system_code = separate_notation_it_coordinate_system_code(answ)
-
-#         flag_print = True
-#         if notation in ACCESIBLE_IT_NUMBER:
-#             it_number = notation
-#         else:
-#             res = get_notation(notation)
-#             if "Hall" == res:
-#                 it_number = get_it_number_by_name_hall(notation)
-#             elif "Schoenflies" == res:
-#                 it_number = get_it_number_by_name_schoenflies(notation)
-#             elif "Hermann-Mauguin" == res:
-#                 res_2 = get_type_hm(notation)
-#                 if "extended" in res_2:
-#                     it_number, it_coordinate_system_codes = get_it_number_it_coordinate_system_codes_by_name_hm_extended(
-#                         notation)
-#                     if (not (it_coordinate_system_code in it_coordinate_system_codes)):
-#                         it_coordinate_system_code = auto_choose_it_coordinate_system_code(it_number,
-#                                                                                           it_coordinate_system_codes)
-#                 elif "full" in res_2:
-#                     it_number = get_it_number_by_name_hm_full(notation)
-#                 elif "short" in res_2:
-#                     it_number = get_it_number_by_name_hm_short(notation)
-#                 else:
-#                     print(f"Notation \"{notation:}\" is not found")
-#                     flag_print = False
-#             else:
-#                 print(f"Notation \"{notation:}\" is not found")
-#                 flag_print = False
-#         if flag_print:
-#             it_coordinate_system_codes = get_it_coordinate_system_codes_by_it_number(it_number)
-#             if (not (it_coordinate_system_code in it_coordinate_system_codes)):
-#                 it_coordinate_system_code = auto_choose_it_coordinate_system_code(it_number, it_coordinate_system_codes)
-#             print_parameters_by_it_number_it_coordinate_system_code(it_number, it_coordinate_system_code)
-#         return flag_print
-
-
-#     flag_print = True
-#     while flag_print:
-#         print(70 * "-")
-#         print(70 * "-")
-#         flag_print = dialog()
-
-#     """
-#     print("\nACCESIBLE_BRAVAIS_TYPE: ")
-#     print_long_list(ACCESIBLE_BRAVAIS_TYPE)
-#     print("\nACCESIBLE_LAUE_CLASS: ")
-#     print_long_list(ACCESIBLE_LAUE_CLASS)
-#     print("\nACCESIBLE_IT_COORDINATE_SYSTEM_CODE: ")
-#     print_long_list(ACCESIBLE_IT_COORDINATE_SYSTEM_CODE)
-#     print("\nACCESIBLE_CENTRING_TYPE: ")
-#     print_long_list(ACCESIBLE_CENTRING_TYPE)
-#     print("\nACCESIBLE_CRYSTAL_SYSTEM: ")
-#     print_long_list(ACCESIBLE_CRYSTAL_SYSTEM)
-#     print("\nACCESIBLE_NAME_HM_SHORT: ")
-#     print_long_list(ACCESIBLE_NAME_HM_SHORT)
-#     print("\nACCESIBLE_NAME_HM_FULL")
-#     print_long_list(ACCESIBLE_NAME_HM_FULL)
-#     print("\nACCESIBLE_NAME_HM_EXTENDED")
-#     print_long_list(ACCESIBLE_NAME_HM_EXTENDED)
-#     print("\nACCESIBLE_NAME_SCHOENFLIES: ")
-#     print_long_list(ACCESIBLE_NAME_SCHOENFLIES)
-#     print("\nACCESIBLE_NAME_HALL_SHORT: ")
-#     print_long_list(ACCESIBLE_NAME_HALL_SHORT)
-#     print("\nACCESIBLE_REFERENCE_SETTING: ")
-#     print_long_list(ACCESIBLE_REFERENCE_SETTING)
-    
-#     print("\nDEFAULT_REFERENCE_TABLE_IT_NUMBER_NAME_HALL_NAME_SCHOENFLIES_NAME_HM_SHORT_REFERENCE_SETTING_IT_COORDINATE_SYSTEM_CODE: ")
-#     print_long_list(DEFAULT_REFERENCE_TABLE_IT_NUMBER_NAME_HALL_NAME_SCHOENFLIES_NAME_HM_SHORT_REFERENCE_SETTING_IT_COORDINATE_SYSTEM_CODE)
-#     print("\nREFERENCE_TABLE_ORTHORHOMBIC_IT_COORDINATE_SYSTEM_CODE_NAME_HM_EXTENDED: ")
-#     print_long_list(REFERENCE_TABLE_ORTHORHOMBIC_IT_COORDINATE_SYSTEM_CODE_NAME_HM_EXTENDED)
-    
-
-#     print("\nD_CENTRING_TYPE_SHIFT: ")
-#     print(D_CENTRING_TYPE_SHIFT)
-#     print("\nD_CRYSTAL_FAMILY_DESCRIPTION: ")
-#     print(D_CRYSTAL_FAMILY_DESCRIPTION)
-#     print("\nD_BRAVAIS_TYPE_CELL_CONSTRAINT_MODE_ABC: ")
-#     print(D_BRAVAIS_TYPE_CELL_CONSTRAINT_MODE_ABC)
-#     print("\nT_BRAVAIS_TYPE_CENTRING_TYPE_CRYSTAL_SYSTEM: ")
-#     print_long_list(T_BRAVAIS_TYPE_CENTRING_TYPE_CRYSTAL_SYSTEM)
-#     """
-
-
-
-# FUNCTIONS = [
-#     transs,
-#     calc_GCF
-# ]
